"""A centralised network controller."""

from typing import Any, Dict, List
from netsquid.nodes import Node


class Controller(Node):
    """A centralised network controller.

    Parameters
    ----------
    name
        The name of the controller.
    port_names : optional
        A list of ports to add to the controller.

    """

    class Ether:
        """Network 'ether' providing instantaneous access to objects for oracle functionality."""

        def __init__(self):
            self._network_objects = None

        @property
        def network_objects(self) -> Dict[str, Any]:
            """Dictionary of network objects."""
            assert self._network_objects is not None
            return self._network_objects

        @network_objects.setter
        def network_objects(self, new_network_objects: Dict[str, Any]):
            assert self._network_objects is None
            self._network_objects = new_network_objects

    def __init__(self, name: str, port_names: List[str] = None):
        super().__init__(name, port_names=port_names)
        self._network_config = None
        self._ether = Controller.Ether()

    @property
    def ether(self) -> 'Controller.Ether':
        """The network ether."""
        return self._ether

    @property
    def network_config(self) -> Dict[str, Any]:
        """The network configuration."""
        assert self._network_config is not None
        return self._network_config

    @network_config.setter
    def network_config(self, new_network_config: Dict[str, Any]):
        assert self._network_config is None
        self._network_config = new_network_config
