"""Default parameter values for NetSquid simulations."""

from typing import Any, Dict


DEFAULT_RANDOM_STATE_SEED = None
"""Default random state seed. ``None`` means that a random state will be randomly generated at the
start of the simulation."""

DEFAULT_TIME_ZERO = 0
"""Default time to start the simulation at."""

DEFAULT_TIME_STEP = 100_000_000
"""Default time step size for checking simulation status."""

DEFAULT_TIME_LIMIT = float("inf")
"""Default time at which to stop the simulation regardless of status."""


def netsquid_defaults_asdict() -> Dict[str, Any]:
    """Get the default netSquid configuration values as a dictionary.

    Returns
    -------
    :
        The dictionary mapping the configuration parameters to their default values.

    """
    return {
        "random_state_seed": DEFAULT_RANDOM_STATE_SEED,
        "time_zero": DEFAULT_TIME_ZERO,
        "time_step": DEFAULT_TIME_STEP,
        "time_limit": DEFAULT_TIME_LIMIT,
    }
